为基金相关的投资顾问及基金经理
提供数据驱动的全市场基金筛选分析工具
提升对基金产品信息的整合、处理和洞察能力
实现对基金产品的变动追踪、关联穿透和对比分析


转正述职
工作概述
辨机项目后端
阶段1:第一个月
确定开发技术（python django）,和产品经理熟悉项目需求和文档，
设计API接口功能和参数，设计数据库表结构，如新闻、基金、标签、基金看板、池子等表设计
按模块开发相应Service实现API功能逻辑，建模拟数据，初步实现头条、看板等界面功能，实现数据筛选和显示
接入sensedeal_core相关中台服务模块，实现接口的用户Oauth认证，短信等模块
确定sentry实现定时任务，RibbitMQ监听消息队列等实现方案。

阶段2:5-7月
接入东财数据库，通过定时任务获取需要数据，存到业务数据库中
根据文档和UI设计实现各个模块的功能，如根据采集数据生成图表、基金详情展示、基金墙、日历生命树等
监听MQ队列实现新闻公告的更新和展示
按照需求处理多个东财数据表和公告，生成对应的数十个基金事件标签
通过任务计算，构建所需要的多个指标和收益标签等
前后端联调修复问题、迭代需求
测试环境、生产环境部署等，包括docker、nginx配置，启动gunicorn、celery、MQ多服务的脚本
辨机正式上线

阶段3:8-9月
功能需求迭代，用户审核、基金经理、基金比较系统等
增加图表展示和所需数据计算，如收益排名和收益平均计算等
对接新算子开发，生成结构化公告数据

不足点：
需要建立更完善的文档和注释，迭代、优化代码结构
太多异步任务，会有报错导致一部分数据没有抓取到的问题，需要建立更完善的日志系统，
目前用flower监控celery任务显示执行时间和异常信息等
对接Sentry可以监控后端服务和定时任务的报错异常，发送邮件通知

下阶段工作计划
继续优化系统和迭代需求，代码易读，数据计算
参与一些大数据计算的研究或框架使用，目前有些需求还无法在期望时间内计算出


工作困惑
